@@ -451,8 +451,7 @@ def native_import(options, src):
             print "Considering binary %s" % binary
         try:
             apt_opts = '-oAPT::Architecture=%s' % options.architecture
-            bin_cache = get_output(['apt-cache',
-                                    '-oAPT::Architecture=%s' % options.architecture, 
+            bin_cache = get_output(['apt-cache', apt_opts,
                                     'show', binary]).splitlines()
         except Exception:
             if options.debug:
@@ -790,8 +789,7 @@ def main():
         # like); we just need to make sure that native imports happen first
         # and then that explicit requests happen in command-line order.
         build_sequence = [d for d in depends if d not in explicit_requests]
-        for pkg in args:
-            build_sequence.append(pkg)
+        build_sequence.extend(args)
     else:
         try:
             build_sequence = tsort.topo_sort(depends)
